# PyDicts  [![PyPI - Downloads](https://img.shields.io/pypi/dm/pydicts?label=Pypi%20downloads)](https://pypi.org/project/pydicts/)

Module to use dictionaries, list of dictionaries and other data structures 

I've developed this module because I needed this kind of methods developing with Django and python

## Links

- https://github.com/turulomio/pydicts/
- https://pypi.org/project/pydicts/

## Documentation

You can access documentation in [Github Pydicts Wiki](https://github.com/turulomio/pydicts/wiki)

## CHANGELOG

### 0.9.0 (2023-12-04)
- Added gettext support
- Improved spanish translation
- Added custom exceptions for each module
- Improved documentation
- Added lol_print method
- myjsonencoder has been included to convert from json to dictionaries

### 0.8.0 (2023-11-26)
- Migrating casts and datetime_functions to pydicts.casts. Utils to make casting easy
- Create lol (List of lists) module

### 0.7.0 (2023-11-04)
- Improved documentation
- Removed duplicated lod_min and lod_max methods
- Added lod_filter_keys function
- Added lod_filter_dictionaries function
- Added lod_clone function
- Added lod_calculate function

### 0.6.0 (2023-07-02)
- Fixed a race condition bug in lod_ymv_transposition_with_percentages

### 0.5.0 (2023-05-04)
- Added support to latex tables from list of dictionaries

### 0.4.0 (2023-04-19)
- Added poetry support
- Added poethepoet support
- Added lod_remove_key

### 0.3.0 (2023-04-16)
- Added lod_ymv_transposition_with_porcentages

### 0.2.0 (2023-04-12)
- Added lod_print with tabulate module
- Improving documentation
- Refactorized modules to lod_xyv, lod_ymmv

### 0.1.0 (2023-04-10)
- First version addapting listdict_functions from reusingcode
